// sdt-project/src/app/page.tsx

import React from "react";
import Link from "next/link";
import Image from "next/image";
import { Button } from "@/components/ui/button";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { faBalanceScale } from "@fortawesome/free-solid-svg-icons";

export default function Home() {
  return (
    <div className="min-h-screen font-sans antialiased flex flex-col">
      <header className="py-6 px-8 border-b">
        <div className="container flex items-center justify-between mx-auto">
          <Link href="/" className="flex items-center font-bold text-xl">
            <FontAwesomeIcon icon={faBalanceScale} className="mr-2" />
            PIL-legal
          </Link>
          <nav className="hidden md:flex items-center space-x-6">
            <a href="#" className="hover:underline">
              Features
            </a>
            <a href="#" className="hover:underline">
              About Us
            </a>
            <a href="#" className="hover:underline">
              Contact
            </a>
            <Link href="/file-pil" className="ml-4">
              <Button size="sm" variant="outline">
                File PIL
              </Button>
            </Link>
          </nav>
          <div className="md:hidden">{/* Hamburger... */}</div>
        </div>
      </header>
      <main className="flex-grow py-20 px-8">
        <div className="container mx-auto text-center">
          <h1 className="text-4xl sm:text-5xl md:text-6xl font-bold mb-6">
            Justice Accessible to All.
          </h1>
          <p className="text-lg text-muted-foreground mb-10 max-w-xl mx-auto">
            PIL-legal empowers individuals and organizations to champion public
            interest litigation with ease and efficiency. Streamline your PIL
            process, from drafting to case management.
          </p>
          <Link href="/file-pil">
            <Button size="lg">File PIL Now</Button>
          </Link>
          <div className="mt-12">
            <Image
              src="/legal-concept.svg"
              alt="Legal Concept Illustration"
              width={800}
              height={400}
              className="mx-auto rounded-lg shadow-md dark:invert-0 invert"
              priority
            />
          </div>
        </div>
      </main>
      {/* ...rest is as before */}
      <section className="py-16 px-8 bg-secondary/10 dark:bg-secondary/20">
        {/* ... */}
      </section>
      <footer className="py-8 px-8 border-t text-center text-sm text-muted-foreground">
        <div className="container mx-auto">
          &copy; {new Date().getFullYear()} PIL-legal. All rights reserved.
        </div>
      </footer>
    </div>
  );
}
